this.name			= "FdL_viper_E_events";
this.author			= "Montana05";
this.description	= "event handler for Viper-E ships";
this.version		= "0.51";
this.copyright		= "2021 Montana05";
this.licence   		= "CC BY-NC-SA 4.0";
"use strict";

this.shipSpawned = function(ship)
{
	this.FdL_viper_shipType = this.ship.dataKey;
		
	if(this.ship.hasRole("escape-capsule"))
	{
		// neutral inits first
		var crewName = expandDescription("[nom]");
		var crewDescription = "a crew member of an evacuated ship";
		var crewRole = "police";  // most of the time
		var crewRank = "Space Lieutenant";  // most common rank
		var crewRace = expandDescription("[FdL_viper_E_GalCop_races_scientific]");  // add a race to the crew members
		var crewBounty = 0;
		var crewInsurance = 0;
				
		// now it's time to be more specific, based on an crew of 1 to 2 person
		// insurance or bounty are defined so there shouldn't be slaves
		switch(this.FdL_viper_shipType) 
		{
			case "FdL_viper_E_escape_capsule_police":
			
				this.$FdL_viper_ranks_array = 
				["Ensign", "Space Junior Lieutenant", "Space Lieutenant", "Lt. Commander"];
				crewRank = 
				$FdL_viper_ranks_array[Math.floor(Math.random() * $FdL_viper_ranks_array.length)];
			
				crewName = ("the " + crewRace + " " + crewRank + " " + crewName);
				crewDescription = "an officer of GalCop Space Police";
				crewInsurance = (this.$getRndInteger(90, 450) + (15 * system.government));  // stable governments pay more
				crewRole = "police";	
				break;

			case "FdL_viper_E_escape_capsule_bhg":

				// ranks for Bounty Hunter Guild taken from Random Hits OXP, all credits to LittleBear
				this.$FdL_viper_bhg_ranks_array = 
				["Outsider", "Recruit", "Vigilante", "Bailiff", "Deputy", "Tracker", "Hunter", "Sheriff", "Provost", "Marshal", "Enforcer", "Executioner", "Judge"];
				crewRank = 
				$FdL_viper_bhg_ranks_array[Math.floor(Math.random() * $FdL_viper_bhg_ranks_array.length)];

				crewName = ("the " + crewRace + " " + crewRank + " " + crewName);
				crewDescription = "a member of the Bounty Hunter Guild";
				crewInsurance = (this.$getRndInteger(90, 450) * 1.10);  // BHG got better insurance conditions
				crewRole = "hunter";	
				break;
						
			case "FdL_viper_E_escape_capsule_bhg_pirate":
				
				crewName = ("the " + crewRace + " " + expandDescription("[FdL_viper_E_pirate_nicknames]") + crewName);
				crewDescription = "a " + expandDescription("[FdL_viper_E_criminals]") +  "wanted by GalCop police";
				crewBounty = (this.$getRndInteger(90, 450) + (15 * system.government));  // stable governments pay extra bonus
				crewRole = "pirate";
				break;	
			
			default: 
				break;
		};

		this.ship.setCrew
		(
			{
				name: crewName,
				short_description: crewDescription,
				role: crewRole,
				species: crewRace,
				insurance: crewInsurance,
				bounty: crewBounty
			}
		);

		// remove individual roles
		this.ship.primaryRole = "escape-capsule";
	}
	else
	{
		var shipRole = this.ship.primaryRole;
		
		// if the ship got no cargo there is a 50% chance that some is added
		if(this.ship.cargoSpaceCapacity > 0 && this.ship.cargoSpaceUsed === 0 && this.$getRndInteger(1, 2) > 1)
		{
			this.ship.adjustCargo("firearms", 1);
		};
		
		// individual role of the ship, will only be called from other OXP's
		switch(shipRole) 
		{
			case "viper":
			case "viper-pursuit":
			case "viper-interceptor":
			case "FdL_viper_E_patrol":
			case "FdL_viper_E_pursuit":
			case "FdL_viper_E_pursuit_bhg_deputy":
			case "FdL_viper_E_interceptor":	
				
				this.ship.primaryRole = "police";
				break;
				
			case "FdL_viper_E_pursuit_bhg":
			case "FdL_viper_E_pursuit_bhg_team_01":

				this.ship.primaryRole = "hunter";
				break;
			
			default: 
				break;
		};
	};
};

this.shipDied = function(whom, why)
{
	if(this.ship.hasRole("escape-capsule"))
	{
		return;
	}
	else
	{
		// neutral inits first
		var podType = "escape-capsule";
		var cargoSpace = this.ship.cargoSpaceCapacity;
		var cargoLoad = this.ship.cargoSpaceUsed;
		
		// remove existing pods first
		if(this.ship.equipmentStatus("EQ_ESCAPE_POD") != "EQUIPMENT_UNAVAILABLE")
		{
			this.ship.removeEquipment("EQ_ESCAPE_POD");
		};

		// prepare relevant pod type
		switch(this.FdL_viper_shipType) 
		{
			case "viper":
			case "viper-pursuit":
			case "viper-interceptor":
			case "FdL_viper_E_patrol":
			case "FdL_viper_E_pursuit":
			case "FdL_viper_E_interceptor":

				podType = "FdL_viper_E_escape_capsule_police";
				break;

			case "FdL_viper_E_pursuit_bhg_deputy":
			case "FdL_viper_E_pursuit_bhg":
			case "FdL_viper_E_pursuit_bhg_team_01":
				
				if(this.ship.bounty > 7)
				{
					podType = "FdL_viper_E_escape_capsule_bhg_pirate";
				}
				else
				{
					podType = "FdL_viper_E_escape_capsule_bhg";
				};
				break;
				
			default: 
				break;	
		};	
		
		// 75% chance that the pilot could eject
		if(this.$getRndInteger(1, 100) > 25)
		{
			system.addShips(podType, 1, this.ship.position);
		};

		// small chance that the ship had prisoners on board (Montanas Ressource Pack 01)
		if(worldScripts["MRP01_ressource_spawn"] && cargoSpace > 0 && cargoLoad == 0 && this.$getRndInteger(1, 10) > 8)
		{
			system.addShips("MRP01_container_prisoners", 1, this.ship.position);
		};	
	};
};	

this.$getRndInteger = function(min, max)
{
	return Math.floor(Math.random() * (max - min + 1) ) + min;
};
